@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 #movies=["The Holy Grail",1975,"Terry Jones & Terry Gilliam",91,["Graham Chapman",["Michael Palin","John Cleese","Terry Gilliam","Eric Idle","Terry Jones"]]]
 
 ############## step 1 ########################
@@ -25,10 +25,11 @@
 """This is the "netster.py" module and it provides one function called print_tool()
 while prints lists that may or may not include nested list."""
 
-def print_tool(the_list):
+def print_tool(the_list,level):
     for each_item in the_list:
         if isinstance(each_item,list):
-            print_tool(each_item)
+            print_tool(each_item,level+1)
         else:
+            for tab_stop in range(level):
+                print("\t", end=' ')
             print(each_item)
-#print_tool(movies)
